sorna-common
============

.. image:: https://badge.fury.io/py/backend.ai-common.svg
   :target: https://badge.fury.io/py/backend.ai-common
   :alt: PyPI version

.. image:: https://img.shields.io/pypi/pyversions/backend.ai-common.svg
   :target: https://pypi.org/project/backend.ai-common/
   :alt: Python Versions

.. image:: https://travis-ci.org/lablup/backend.ai-common.svg?branch=master
   :target: https://travis-ci.org/lablup/backend.ai-common
   :alt: Build Status

.. image:: https://codecov.io/gh/lablup/backend.ai-common/branch/master/graph/badge.svg
   :target: https://codecov.io/gh/lablup/backend.ai-common
   :alt: Code Coverage


Common utilities library for Backend.AI


Installation
------------

.. code-block:: console

   $ pip install backend.ai-common

For development
~~~~~~~~~~~~~~~

.. code-block:: console

   $ pip install -r requirements-dev.txt
